@@ -1,10 +1,13 @@
 from .url_utils import *
-def reconstructUrlFromUrlParse(url=None, parsed=None, parsed_dict=None):
-    keys = ['scheme','netloc','path','params','query','fragment']
+def get_parsed_dict(url=None, parsed=None, parsed_dict=None):
     if url and not parsed:
-        parsed_dict = parse_url(url=url)
+        parsed = parse_url(url)
     if parsed and not parsed_dict:
         parsed_dict = parse_url(parsed=parsed)
+    return parsed_dict 
+def reconstructUrlFromUrlParse(url=None, parsed=None, parsed_dict=None):
+    keys = ['scheme','netloc','path','params','query','fragment']
+    parsed_dict =  get_parsed_dict(url=url, parsed=parsed, parsed_dict=parsed_dict)
     if parsed_dict:
         scheme = parsed_dict.get('scheme')
         nuUrl = ''
@@ -21,12 +24,8 @@ def reconstructUrlFromUrlParse(url=None, parsed=None, parsed_dict=None):
                 nuUrl += value
         return nuUrl
     return url
-
-def get_youtube_url(url=None, parsed=None, parsed_dict=None):
-    if url and not parsed:
-        parsed_dict = parse_url(url=url)
-    if parsed and not parsed_dict:
-        parsed_dict = parse_url(parsed=parsed)
+def get_youtube_parsed_dict(url=None, parsed=None, parsed_dict=None):
+    parsed_dict =  get_parsed_dict(url=url, parsed=parsed, parsed_dict=parsed_dict)
     if parsed_dict:
         netloc = parsed_dict.get("netloc")
         domain = (netloc or {}).get('domain') or ''
@@ -48,26 +47,27 @@ def get_youtube_url(url=None, parsed=None, parsed_dict=None):
                     v_query = eatAll(path, ['/'])
             parsed_dict['path'] = '/watch'
             parsed_dict['query'] = {'v': v_query} if v_query else {}
-            return reconstructUrlFromUrlParse(parsed_dict=parsed_dict)
+            return parsed_dict
+def get_youtube_v_query(url=None, parsed=None, parsed_dict=None):
+    parsed_dict =  get_youtube_parsed_dict(url=url, parsed=parsed, parsed_dict=parsed_dict)
+    v_query = parsed_dict.get('query',{}).get('v')
+    return v_query
+def get_youtube_url(url=None, parsed=None, parsed_dict=None):
+    parsed_dict =  get_youtube_parsed_dict(url=url, parsed=parsed, parsed_dict=parsed_dict)
+    return reconstructUrlFromUrlParse(parsed_dict=parsed_dict)
 def get_threads_url(url=None,parsed=None, parsed_dict =None ):
-    if url and not parsed:
-        parsed = parse_url(url)
-    if parsed and not parsed_dict:
-        parsed_dict = parse_url(parsed=parsed)
+    parsed_dict =  get_parsed_dict(url=url, parsed=parsed, parsed_dict=parsed_dict)
     if parsed_dict:
         netloc = parsed_dict.get("netloc")
-        domain = netloc.get('domain')
+        domain = (netloc or {}).get('domain') or ''
         if domain.startswith('threads'):
             netloc['www']=True
-            netloc['domain'] ='youtube'
+            netloc['domain'] ='threads'
             netloc['extention'] = '.net'
             parsed['netloc']=netloc
             return reconstructUrlFromUrlParse(url=url,parsed=parsed,parsed_dict=None)  
 def get_corrected_url(url=None,parsed=None, parsed_dict =None ):
-    if url and not parsed:
-        parsed_dict = parse_url(url=url)
-    if parsed and not parsed_dict:
-        parsed_dict = parse_url(parsed=parsed)
+    parsed_dict =  get_parsed_dict(url=url, parsed=parsed, parsed_dict=parsed_dict)
     if parsed_dict:
         funcs = [get_threads_url,get_youtube_url,reconstructUrlFromUrlParse]
         for func in funcs:
